==> jc-1.4.0.tar.gz: javax/print/attribute/standard/PrinterInfo.h <==
// public final class javax.print.attribute.standard.PrinterInfo

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 2c49b1290ea91885 javax_print_attribute_TextSyntax
// @dep_class 9a4b63f69da1ab86 javax_print_attribute_standard_PrinterInfo

// header file dependencies
// @dep_header javax_print_attribute_TextSyntax

#include "javax/print/attribute/TextSyntax.h"

#ifndef _JC_javax_print_attribute_standard_PrinterInfo_H_
#define _JC_javax_print_attribute_standard_PrinterInfo_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Locale$object;

// Typedefs
typedef struct _jc_javax_print_attribute_standard_PrinterInfo$sub_refs	_jc_javax_print_attribute_standard_PrinterInfo$sub_refs;
typedef struct _jc_javax_print_attribute_standard_PrinterInfo$sub_nonrefs	_jc_javax_print_attribute_standard_PrinterInfo$sub_nonrefs;
typedef struct _jc_javax_print_attribute_standard_PrinterInfo$refs	_jc_javax_print_attribute_standard_PrinterInfo$refs;
typedef struct _jc_javax_print_attribute_standard_PrinterInfo$nonrefs	_jc_javax_print_attribute_standard_PrinterInfo$nonrefs;
typedef struct _jc_javax_print_attribute_standard_PrinterInfo$object	_jc_javax_print_attribute_standard_PrinterInfo$object;

typedef struct _jc_javax_print_attribute_standard_PrinterInfo$fields_struct	_jc_javax_print_attribute_standard_PrinterInfo$fields_struct;
typedef const struct _jc_javax_print_attribute_standard_PrinterInfo$vmethods	_jc_javax_print_attribute_standard_PrinterInfo$vmethods;
typedef const struct _jc_javax_print_attribute_standard_PrinterInfo$vtable	_jc_javax_print_attribute_standard_PrinterInfo$vtable;
typedef const struct _jc_javax_print_attribute_standard_PrinterInfo$vtype	_jc_javax_print_attribute_standard_PrinterInfo$vtype;

// Class fields structure
struct _jc_javax_print_attribute_standard_PrinterInfo$fields_struct {
	struct _jc_java_lang_Class$object	*class__24javax__24print__24attribute__24standard__24PrinterInfo;
	jlong	serialVersionUID;
};
extern _jc_javax_print_attribute_standard_PrinterInfo$fields_struct _jc_javax_print_attribute_standard_PrinterInfo$class_fields;

// Constructors
extern void _jc_javax_print_attribute_standard_PrinterInfo$method$_init$cc9f9d14d2541299(_jc_env *, struct _jc_javax_print_attribute_standard_PrinterInfo$object *, struct _jc_java_lang_String$object *, struct _jc_java_util_Locale$object *);

// Virtual methods
extern jboolean _jc_javax_print_attribute_standard_PrinterInfo$method$equals$8a15e0625571c581(_jc_env *, struct _jc_javax_print_attribute_standard_PrinterInfo$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_standard_PrinterInfo$method$getCategory$1a83ac042894bcc8(_jc_env *, struct _jc_javax_print_attribute_standard_PrinterInfo$object *);
extern struct _jc_java_lang_String$object *_jc_javax_print_attribute_standard_PrinterInfo$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_javax_print_attribute_standard_PrinterInfo$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_print_attribute_standard_PrinterInfo$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_javax_print_attribute_standard_PrinterInfo$method_info$getCategory$1a83ac042894bcc8;
extern _jc_method _jc_javax_print_attribute_standard_PrinterInfo$method_info$getName$bec186f2ce7e1882;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_standard_PrinterInfo$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean);

// Virtual methods structure
struct _jc_javax_print_attribute_standard_PrinterInfo$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_javax_print_attribute_standard_PrinterInfo$object *, struct _jc_java_lang_Object$object *);
	struct _jc_java_lang_Class$object	*(*getCategory$1a83ac042894bcc8)(_jc_env *, struct _jc_javax_print_attribute_standard_PrinterInfo$object *);
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_javax_print_attribute_standard_PrinterInfo$object *);
};

// Vtable
struct _jc_javax_print_attribute_standard_PrinterInfo$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_print_attribute_TextSyntax$vmethods	javax_print_attribute_TextSyntax;
	_jc_javax_print_attribute_standard_PrinterInfo$vmethods	javax_print_attribute_standard_PrinterInfo;
};

// Vtype
struct _jc_javax_print_attribute_standard_PrinterInfo$vtype {
	_jc_type			type;
	_jc_javax_print_attribute_standard_PrinterInfo$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_attribute_standard_PrinterInfo$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_print_attribute_standard_PrinterInfo$refs {
    _jc_javax_print_attribute_standard_PrinterInfo$sub_refs	javax_print_attribute_standard_PrinterInfo;
    _jc_javax_print_attribute_TextSyntax$sub_refs	javax_print_attribute_TextSyntax;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_attribute_standard_PrinterInfo$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_attribute_standard_PrinterInfo$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_print_attribute_TextSyntax$sub_nonrefs	javax_print_attribute_TextSyntax;
    _jc_javax_print_attribute_standard_PrinterInfo$sub_nonrefs	javax_print_attribute_standard_PrinterInfo;
};

// Object instance structure
struct _jc_javax_print_attribute_standard_PrinterInfo$object {
	_jc_javax_print_attribute_standard_PrinterInfo$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_attribute_standard_PrinterInfo$vtype	*vtype;
	_jc_javax_print_attribute_standard_PrinterInfo$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_attribute_standard_PrinterInfo$vtype _jc_javax_print_attribute_standard_PrinterInfo$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_attribute_standard_PrinterInfo, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_attribute_standard_PrinterInfo$class_object;

#endif	/* _JC_javax_print_attribute_standard_PrinterInfo_H_ */

==> jc-1.4.6.tar.gz: javax/print/attribute/standard/PrinterInfo.h <==
// public final class javax.print.attribute.standard.PrinterInfo

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 2c49b1290ea91885 javax_print_attribute_TextSyntax
// @dep_class 9a4b63f69da1ab86 javax_print_attribute_standard_PrinterInfo

// header file dependencies
// @dep_header javax_print_attribute_TextSyntax

#include "javax/print/attribute/TextSyntax.h"

#ifndef _JC_javax_print_attribute_standard_PrinterInfo_H_
#define _JC_javax_print_attribute_standard_PrinterInfo_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Locale$object;

// Typedefs
typedef struct _jc_javax_print_attribute_standard_PrinterInfo$sub_refs	_jc_javax_print_attribute_standard_PrinterInfo$sub_refs;
typedef struct _jc_javax_print_attribute_standard_PrinterInfo$sub_nonrefs	_jc_javax_print_attribute_standard_PrinterInfo$sub_nonrefs;
typedef struct _jc_javax_print_attribute_standard_PrinterInfo$refs	_jc_javax_print_attribute_standard_PrinterInfo$refs;
typedef struct _jc_javax_print_attribute_standard_PrinterInfo$nonrefs	_jc_javax_print_attribute_standard_PrinterInfo$nonrefs;
typedef struct _jc_javax_print_attribute_standard_PrinterInfo$object	_jc_javax_print_attribute_standard_PrinterInfo$object;

typedef struct _jc_javax_print_attribute_standard_PrinterInfo$fields_struct	_jc_javax_print_attribute_standard_PrinterInfo$fields_struct;
typedef const struct _jc_javax_print_attribute_standard_PrinterInfo$vmethods	_jc_javax_print_attribute_standard_PrinterInfo$vmethods;
typedef const struct _jc_javax_print_attribute_standard_PrinterInfo$vtable	_jc_javax_print_attribute_standard_PrinterInfo$vtable;
typedef const struct _jc_javax_print_attribute_standard_PrinterInfo$vtype	_jc_javax_print_attribute_standard_PrinterInfo$vtype;

// Class fields structure
struct _jc_javax_print_attribute_standard_PrinterInfo$fields_struct {
	struct _jc_java_lang_Class$object	*class__24javax__24print__24attribute__24standard__24PrinterInfo;
	jlong	serialVersionUID;
};
extern _jc_javax_print_attribute_standard_PrinterInfo$fields_struct _jc_javax_print_attribute_standard_PrinterInfo$class_fields;

// Constructors
extern void _jc_javax_print_attribute_standard_PrinterInfo$method$_init$cc9f9d14d2541299(_jc_env *, struct _jc_javax_print_attribute_standard_PrinterInfo$object *, struct _jc_java_lang_String$object *, struct _jc_java_util_Locale$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_javax_print_attribute_standard_PrinterInfo$method$equals$8a15e0625571c581(_jc_env *, struct _jc_javax_print_attribute_standard_PrinterInfo$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_standard_PrinterInfo$method$getCategory$1a83ac042894bcc8(_jc_env *, struct _jc_javax_print_attribute_standard_PrinterInfo$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_javax_print_attribute_standard_PrinterInfo$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_javax_print_attribute_standard_PrinterInfo$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_print_attribute_standard_PrinterInfo$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_javax_print_attribute_standard_PrinterInfo$method_info$getCategory$1a83ac042894bcc8;
extern _jc_method _jc_javax_print_attribute_standard_PrinterInfo$method_info$getName$bec186f2ce7e1882;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_standard_PrinterInfo$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_print_attribute_standard_PrinterInfo$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_javax_print_attribute_standard_PrinterInfo$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Class$object	*(*getCategory$1a83ac042894bcc8)(_jc_env *, struct _jc_javax_print_attribute_standard_PrinterInfo$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_javax_print_attribute_standard_PrinterInfo$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_print_attribute_standard_PrinterInfo$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_print_attribute_TextSyntax$vmethods	javax_print_attribute_TextSyntax;
	_jc_javax_print_attribute_standard_PrinterInfo$vmethods	javax_print_attribute_standard_PrinterInfo;
};

// Vtype
struct _jc_javax_print_attribute_standard_PrinterInfo$vtype {
	_jc_type			type;
	_jc_javax_print_attribute_standard_PrinterInfo$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_attribute_standard_PrinterInfo$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_print_attribute_standard_PrinterInfo$refs {
    _jc_javax_print_attribute_standard_PrinterInfo$sub_refs	javax_print_attribute_standard_PrinterInfo;
    _jc_javax_print_attribute_TextSyntax$sub_refs	javax_print_attribute_TextSyntax;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_attribute_standard_PrinterInfo$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_attribute_standard_PrinterInfo$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_print_attribute_TextSyntax$sub_nonrefs	javax_print_attribute_TextSyntax;
    _jc_javax_print_attribute_standard_PrinterInfo$sub_nonrefs	javax_print_attribute_standard_PrinterInfo;
};

// Object instance structure
struct _jc_javax_print_attribute_standard_PrinterInfo$object {
	_jc_javax_print_attribute_standard_PrinterInfo$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_attribute_standard_PrinterInfo$vtype	*vtype;
	_jc_javax_print_attribute_standard_PrinterInfo$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_attribute_standard_PrinterInfo$vtype _jc_javax_print_attribute_standard_PrinterInfo$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_attribute_standard_PrinterInfo, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_attribute_standard_PrinterInfo$class_object;

#endif	/* _JC_javax_print_attribute_standard_PrinterInfo_H_ */
